 /*
 * Project       : ipv6calc
 * File          : dbasn_assignment.h
 * Version       : $Id: 17ce140d3b0e374e236139f0dcff08550df38c7a $
 * Generated     : Mon Jun 16 06:13:29 2025
 * Data copyright: IANA
 *
 * Information:
 *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
 */

#include "libipv6calc.h"

/*@unused@*/ static const char* dbasn_registry_status __attribute__ ((__unused__)) = "IANA/20250117";

static const s_asn_assignment dbasn_assignment[] = {
	{          1,       1876, REGISTRY_ARIN       },
	{       1877,       1901, REGISTRY_RIPENCC    },
	{       1902,       2042, REGISTRY_ARIN       },
	{       2043,       2043, REGISTRY_RIPENCC    },
	{       2044,       2046, REGISTRY_ARIN       },
	{       2047,       2047, REGISTRY_RIPENCC    },
	{       2048,       2106, REGISTRY_ARIN       },
	{       2107,       2136, REGISTRY_RIPENCC    },
	{       2137,       2584, REGISTRY_ARIN       },
	{       2585,       2614, REGISTRY_RIPENCC    },
	{       2615,       2772, REGISTRY_ARIN       },
	{       2773,       2822, REGISTRY_RIPENCC    },
	{       2823,       2829, REGISTRY_ARIN       },
	{       2830,       2879, REGISTRY_RIPENCC    },
	{       2880,       3153, REGISTRY_ARIN       },
	{       3154,       3353, REGISTRY_RIPENCC    },
	{       3354,       4607, REGISTRY_ARIN       },
	{       4608,       4865, REGISTRY_APNIC      },
	{       4866,       5376, REGISTRY_ARIN       },
	{       5377,       5631, REGISTRY_RIPENCC    },
	{       5632,       6655, REGISTRY_ARIN       },
	{       6656,       6911, REGISTRY_RIPENCC    },
	{       6912,       7466, REGISTRY_ARIN       },
	{       7467,       7722, REGISTRY_APNIC      },
	{       7723,       8191, REGISTRY_ARIN       },
	{       8192,       9215, REGISTRY_RIPENCC    },
	{       9216,      10239, REGISTRY_APNIC      },
	{      10240,      12287, REGISTRY_ARIN       },
	{      12288,      13311, REGISTRY_RIPENCC    },
	{      13312,      15359, REGISTRY_ARIN       },
	{      15360,      16383, REGISTRY_RIPENCC    },
	{      16384,      17407, REGISTRY_ARIN       },
	{      17408,      18431, REGISTRY_APNIC      },
	{      18432,      20479, REGISTRY_ARIN       },
	{      20480,      21503, REGISTRY_RIPENCC    },
	{      21504,      23455, REGISTRY_ARIN       },
	{      23457,      23551, REGISTRY_ARIN       },
	{      23552,      24575, REGISTRY_APNIC      },
	{      24576,      25599, REGISTRY_RIPENCC    },
	{      25600,      26623, REGISTRY_ARIN       },
	{      26624,      27647, REGISTRY_ARIN       },
	{      27648,      28671, REGISTRY_LACNIC     },
	{      28672,      29695, REGISTRY_RIPENCC    },
	{      29696,      30719, REGISTRY_ARIN       },
	{      30720,      31743, REGISTRY_RIPENCC    },
	{      31744,      32767, REGISTRY_ARIN       },
	{      32768,      33791, REGISTRY_ARIN       },
	{      33792,      34815, REGISTRY_RIPENCC    },
	{      34816,      35839, REGISTRY_RIPENCC    },
	{      35840,      36863, REGISTRY_ARIN       },
	{      36864,      37887, REGISTRY_AFRINIC    },
	{      37888,      38911, REGISTRY_APNIC      },
	{      38912,      39935, REGISTRY_RIPENCC    },
	{      39936,      40959, REGISTRY_ARIN       },
	{      40960,      41983, REGISTRY_RIPENCC    },
	{      41984,      43007, REGISTRY_RIPENCC    },
	{      43008,      44031, REGISTRY_RIPENCC    },
	{      44032,      45055, REGISTRY_RIPENCC    },
	{      45056,      46079, REGISTRY_APNIC      },
	{      46080,      47103, REGISTRY_ARIN       },
	{      47104,      48127, REGISTRY_RIPENCC    },
	{      48128,      49151, REGISTRY_RIPENCC    },
	{      49152,      50175, REGISTRY_RIPENCC    },
	{      50176,      51199, REGISTRY_RIPENCC    },
	{      51200,      52223, REGISTRY_RIPENCC    },
	{      52224,      53247, REGISTRY_LACNIC     },
	{      53248,      54271, REGISTRY_ARIN       },
	{      54272,      55295, REGISTRY_ARIN       },
	{      55296,      56319, REGISTRY_APNIC      },
	{      56320,      57343, REGISTRY_RIPENCC    },
	{      57344,      58367, REGISTRY_RIPENCC    },
	{      58368,      59391, REGISTRY_APNIC      },
	{      59392,      60415, REGISTRY_RIPENCC    },
	{      60416,      61439, REGISTRY_RIPENCC    },
	{      61440,      61951, REGISTRY_LACNIC     },
	{      61952,      62463, REGISTRY_RIPENCC    },
	{      62464,      63487, REGISTRY_ARIN       },
	{      63488,      63999, REGISTRY_APNIC      },
	{      64000,      64098, REGISTRY_APNIC      },
	{      64099,      64197, REGISTRY_LACNIC     },
	{      64198,      64296, REGISTRY_ARIN       },
	{      64297,      64395, REGISTRY_APNIC      },
	{      64396,      64495, REGISTRY_RIPENCC    },
	{     131072,     132095, REGISTRY_APNIC      },
	{     132096,     133119, REGISTRY_APNIC      },
	{     133120,     133631, REGISTRY_APNIC      },
	{     133632,     134556, REGISTRY_APNIC      },
	{     134557,     135580, REGISTRY_APNIC      },
	{     135581,     136505, REGISTRY_APNIC      },
	{     136506,     137529, REGISTRY_APNIC      },
	{     137530,     138553, REGISTRY_APNIC      },
	{     138554,     139577, REGISTRY_APNIC      },
	{     139578,     140601, REGISTRY_APNIC      },
	{     140602,     141625, REGISTRY_APNIC      },
	{     141626,     142649, REGISTRY_APNIC      },
	{     142650,     143673, REGISTRY_APNIC      },
	{     143674,     144697, REGISTRY_APNIC      },
	{     144698,     145721, REGISTRY_APNIC      },
	{     145722,     146745, REGISTRY_APNIC      },
	{     146746,     147769, REGISTRY_APNIC      },
	{     147770,     148793, REGISTRY_APNIC      },
	{     148794,     149817, REGISTRY_APNIC      },
	{     149818,     150841, REGISTRY_APNIC      },
	{     150842,     151865, REGISTRY_APNIC      },
	{     151866,     152889, REGISTRY_APNIC      },
	{     152890,     153913, REGISTRY_APNIC      },
	{     153914,     154937, REGISTRY_APNIC      },
	{     154938,     155961, REGISTRY_APNIC      },
	{     196608,     197631, REGISTRY_RIPENCC    },
	{     197632,     198655, REGISTRY_RIPENCC    },
	{     198656,     199679, REGISTRY_RIPENCC    },
	{     199680,     200191, REGISTRY_RIPENCC    },
	{     200192,     201215, REGISTRY_RIPENCC    },
	{     201216,     202239, REGISTRY_RIPENCC    },
	{     202240,     203263, REGISTRY_RIPENCC    },
	{     203264,     204287, REGISTRY_RIPENCC    },
	{     204288,     205211, REGISTRY_RIPENCC    },
	{     205212,     206235, REGISTRY_RIPENCC    },
	{     206236,     207259, REGISTRY_RIPENCC    },
	{     207260,     208283, REGISTRY_RIPENCC    },
	{     208284,     209307, REGISTRY_RIPENCC    },
	{     209308,     210331, REGISTRY_RIPENCC    },
	{     210332,     211355, REGISTRY_RIPENCC    },
	{     211356,     212379, REGISTRY_RIPENCC    },
	{     212380,     213403, REGISTRY_RIPENCC    },
	{     213404,     214427, REGISTRY_RIPENCC    },
	{     214428,     215451, REGISTRY_RIPENCC    },
	{     215452,     216475, REGISTRY_RIPENCC    },
	{     262144,     263167, REGISTRY_LACNIC     },
	{     263168,     263679, REGISTRY_LACNIC     },
	{     263680,     264604, REGISTRY_LACNIC     },
	{     264605,     265628, REGISTRY_LACNIC     },
	{     265629,     266652, REGISTRY_LACNIC     },
	{     266653,     267676, REGISTRY_LACNIC     },
	{     267677,     268700, REGISTRY_LACNIC     },
	{     268701,     269724, REGISTRY_LACNIC     },
	{     269725,     270748, REGISTRY_LACNIC     },
	{     270749,     271772, REGISTRY_LACNIC     },
	{     271773,     272796, REGISTRY_LACNIC     },
	{     272797,     273820, REGISTRY_LACNIC     },
	{     273821,     274844, REGISTRY_LACNIC     },
	{     327680,     328703, REGISTRY_AFRINIC    },
	{     328704,     329727, REGISTRY_AFRINIC    },
	{     393216,     394239, REGISTRY_ARIN       },
	{     394240,     395164, REGISTRY_ARIN       },
	{     395165,     396188, REGISTRY_ARIN       },
	{     396189,     397212, REGISTRY_ARIN       },
	{     397213,     398236, REGISTRY_ARIN       },
	{     398237,     399260, REGISTRY_ARIN       },
	{     399261,     400284, REGISTRY_ARIN       },
	{     400285,     401308, REGISTRY_ARIN       },
	{     401309,     402332, REGISTRY_ARIN       },

};

